==> huaweicloudsdkcse-3.1.75-py2.py3-none-any.whl: huaweicloudsdkcse/v1/model/engine_rbac_pwd.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class EngineRbacPwd:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'pwd': 'str'
    }

    attribute_map = {
        'pwd': 'pwd'
    }

    def __init__(self, pwd=None):
        """EngineRbacPwd

        The model defined in huaweicloud sdk

        :param pwd: 开启安全认证的微服务引擎专享版默认root帐号的密码
        :type pwd: str
        """
        
        

        self._pwd = None
        self.discriminator = None

        if pwd is not None:
            self.pwd = pwd

    @property
    def pwd(self):
        """Gets the pwd of this EngineRbacPwd.

        开启安全认证的微服务引擎专享版默认root帐号的密码

        :return: The pwd of this EngineRbacPwd.
        :rtype: str
        """
        return self._pwd

    @pwd.setter
    def pwd(self, pwd):
        """Sets the pwd of this EngineRbacPwd.

        开启安全认证的微服务引擎专享版默认root帐号的密码

        :param pwd: The pwd of this EngineRbacPwd.
        :type pwd: str
        """
        self._pwd = pwd

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EngineRbacPwd):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcse-3.1.126-py2.py3-none-any.whl: huaweicloudsdkcse/v1/model/engine_rbac_pwd.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class EngineRbacPwd:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'pwd': 'str'
    }

    attribute_map = {
        'pwd': 'pwd'
    }

    def __init__(self, pwd=None):
        """EngineRbacPwd

        The model defined in huaweicloud sdk

        :param pwd: 开启安全认证的ServiceComb引擎专享版默认root帐号的密码
        :type pwd: str
        """
        
        

        self._pwd = None
        self.discriminator = None

        if pwd is not None:
            self.pwd = pwd

    @property
    def pwd(self):
        """Gets the pwd of this EngineRbacPwd.

        开启安全认证的ServiceComb引擎专享版默认root帐号的密码

        :return: The pwd of this EngineRbacPwd.
        :rtype: str
        """
        return self._pwd

    @pwd.setter
    def pwd(self, pwd):
        """Sets the pwd of this EngineRbacPwd.

        开启安全认证的ServiceComb引擎专享版默认root帐号的密码

        :param pwd: The pwd of this EngineRbacPwd.
        :type pwd: str
        """
        self._pwd = pwd

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EngineRbacPwd):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
